<?php

add_action('admin_menu', 'create_theme_options_page');
add_action('admin_init', 'register_and_build_fields');

function create_theme_options_page() {
   add_menu_page('Chronos Under Construction', 'Chronos', 'administrator', __FILE__, 'options_page_fn');
}

function register_and_build_fields() {
	register_setting('plugin_options', 'plugin_options', 'validate_setting');
	add_settings_section('main_section', 'Main Settings', 'section_cb', __FILE__);

	add_settings_field('site_title', 'Site Title:', 'site_title_function', __FILE__, 'main_section'); //Page Title
	add_settings_field('logo', 'Logo:', 'logo_function', __FILE__, 'main_section'); // LOGO
	add_settings_field('logo_alt', 'Logo alt tag:', 'logo_alt_setting', __FILE__, 'main_section'); // LOGO ALT TAG

	add_settings_field('page_header', 'Page header:', 'page_header_setting', __FILE__, 'main_section');
	add_settings_field('info_text', 'Info text:', 'info_text_setting', __FILE__, 'main_section');
	add_settings_field('color_scheme', 'Color Scheme:', 'color_scheme_setting', __FILE__, 'main_section');


	add_settings_field('date_desc', '<span style="font-size: 11px; font-weight: bold;">Set the target date (launch date) below:</span>', 'date_desc_setting', __FILE__, 'main_section');
	add_settings_field('year', 'Year:', 'year_setting', __FILE__, 'main_section');
	add_settings_field('month', 'Month:', 'month_setting', __FILE__, 'main_section');   
	add_settings_field('day', 'Day:', 'day_setting', __FILE__, 'main_section');
	add_settings_field('hour', 'Hour:', 'hour_setting', __FILE__, 'main_section');
	add_settings_field('minute', 'Minute:', 'minute_setting', __FILE__, 'main_section');
	add_settings_field('second', 'Second:', 'second_setting', __FILE__, 'main_section');
	add_settings_field('displaythreedigits', 'Display three digit days?', 'displaythreedigits_setting', __FILE__, 'main_section');	
	
	add_settings_field('progress', 'Progress (0 to 100):', 'progress_setting', __FILE__, 'main_section');	

	add_settings_field('social_desc', '<span style="font-size: 11px; font-weight: bold;">Social interaction settings:</span>', 'social_desc_setting', __FILE__, 'main_section');
	add_settings_field('displaytweet', 'Display latest tweet?', 'displaytweet_setting', __FILE__, 'main_section');	
	add_settings_field('twittername', 'Twitter username:', 'twittername_setting', __FILE__, 'main_section');	

	add_settings_field('displaytwittericon', 'Display twitter icon?', 'displaytwittericon_setting', __FILE__, 'main_section');
	add_settings_field('twitterlink', 'Link to your twitter page:', 'twitterlink_setting', __FILE__, 'main_section');

	add_settings_field('displayfbicon', 'Display Facebook icon?', 'displayfbicon_setting', __FILE__, 'main_section');
	add_settings_field('facebooklink', 'Link to your Facebook page:', 'facebooklink_setting', __FILE__, 'main_section');	

	add_settings_field('rssdisplay', 'Display RSS feed icon?', 'rssdisplay_setting', __FILE__, 'main_section');
	add_settings_field('rss', 'Link to your RSS feed:', 'rss_setting', __FILE__, 'main_section');


	add_settings_field('sendmailto', 'Contact email address:', 'sendmailto_setting', __FILE__, 'main_section');

	add_settings_field('hidesocial', 'Hide all social icons?', 'hidesocial_setting', __FILE__, 'main_section');	
	
	add_settings_field('harvest_desc', '<span style="font-size: 11px; font-weight: bold;">MySQL & XML settings:</span>', 'harvest_desc_setting', __FILE__, 'main_section');

	add_settings_field('useSQL', 'Use SQL?', 'useSQL_setting', __FILE__, 'main_section');
	add_settings_field('dbhost', 'Database hostname:', 'dbhost_setting', __FILE__, 'main_section');
	add_settings_field('dbdatabase', 'Database name:', 'dbdatabase_setting', __FILE__, 'main_section');
	add_settings_field('dbusername', 'Database username:', 'dbusername_setting', __FILE__, 'main_section');
	add_settings_field('dbpassword', 'Database password:', 'dbpassword_setting', __FILE__, 'main_section');

	add_settings_field('useXML', 'Store data in XML file?', 'useXML_setting', __FILE__, 'main_section');

	add_settings_field('confletter_desc', '<span style="font-size: 11px; font-weight: bold;">Confirmation letter settings:</span>', 'confletter_desc_setting', __FILE__, 'main_section');

	add_settings_field('email_sender', 'From (Name):', 'email_sender_setting', __FILE__, 'main_section');
	add_settings_field('email_from', 'From (Email Address):', 'email_from_setting', __FILE__, 'main_section');
	add_settings_field('email_subject', 'Subject:', 'email_subject_setting', __FILE__, 'main_section');
	add_settings_field('email_body', 'Message:', 'email_body_setting', __FILE__, 'main_section');


}

function options_page_fn() {
?>



<h2>Chronos Template Options & Settings Page</h2>


<form method="post" action="options.php" enctype="multipart/form-data">
<?php settings_fields('plugin_options'); ?>
<?php do_settings_sections(__FILE__); ?>
<p class="submit">
<input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" />
</p>
</form>

<?php
}

// Site Title
function site_title_function() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[site_title]' type='text' value='{$options['site_title']}' />";
}

// Logo
function logo_function() {
   echo '<input type="file" name="logo" />';
}

// Logo Alt
function logo_alt_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[logo_alt]' type='text' value='{$options['logo_alt']}' />";
}

// Header
function page_header_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[page_header]' type='text' value='{$options['page_header']}' />";
}

// Info Text
function info_text_setting() {
   $options = get_option('plugin_options');
   echo "<textarea name='plugin_options[info_text]' rows='10' cols='60' type='textarea'>{$options['info_text']}</textarea>";
}

// Color Scheme
function color_scheme_setting() {
   $options = get_option('plugin_options');
   $items = array("blue", "black", "green", "pink", "purple", "red", "seagreen", "yellow");

   echo "<select name='plugin_options[color_scheme]'>";
   foreach ($items as $item) {
      $selected = ( $options['color_scheme'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Date description
function date_desc_setting() {
   $options = get_option('plugin_options');
}

// Year
function year_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[year]' type='text' value='{$options['year']}' />";
}

// Month
function month_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[month]' type='text' value='{$options['month']}' />";
}

// Day
function day_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[day]' type='text' value='{$options['day']}' />";
}

// Hour
function hour_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[hour]' type='text' value='{$options['hour']}' />";
}

// Minute
function minute_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[minute]' type='text' value='{$options['minute']}' />";
}

// Second
function second_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[second]' type='text' value='{$options['second']}' />";
}

// Display three digits
function displaythreedigits_setting() {
   $options = get_option('plugin_options');
   $items = array("true", "false");
   echo "<select name='plugin_options[displaythreedigits]'>";
   foreach ($items as $item) {
      $selected = ( $options['displaythreedigits'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}


// Progress
function progress_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[progress]' type='text' value='{$options['progress']}' />";
}

// Social interaction
function social_desc_setting() {
   $options = get_option('plugin_options');
}

// Latest tweet display
function displaytweet_setting() {
   $options = get_option('plugin_options');
   $items = array("yes", "no");

   echo "<select name='plugin_options[displaytweet]'>";
   foreach ($items as $item) {
      $selected = ( $options['displaytweet'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Twitter Name
function twittername_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[twittername]' type='text' value='{$options['twittername']}' />";
}

// Display twitter icon?
function displaytwittericon_setting() {
   $options = get_option('plugin_options');
   $items = array("yes", "no");

   echo "<select name='plugin_options[displaytwittericon]'>";
   foreach ($items as $item) {
      $selected = ( $options['displaytwittericon'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Twitter Link
function twitterlink_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[twitterlink]' type='text' value='{$options['twitterlink']}' />";
}

// Display twitter icon?
function displayfbicon_setting() {
   $options = get_option('plugin_options');
   $items = array("yes", "no");

   echo "<select name='plugin_options[displayfbicon]'>";
   foreach ($items as $item) {
      $selected = ( $options['displayfbicon'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Facebook Link
function facebooklink_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[facebooklink]' type='text' value='{$options['facebooklink']}' />";
}

// RSS display
function rssdisplay_setting() {
   $options = get_option('plugin_options');
   $items = array("yes", "no");

   echo "<select name='plugin_options[rssdisplay]'>";
   foreach ($items as $item) {
      $selected = ( $options['rssdisplay'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// RSS Link
function rss_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[rss]' type='text' value='{$options['rss']}' />";
}

// Send mail to
function sendmailto_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[sendmailto]' type='text' value='{$options['sendmailto']}' />";
}

// Hide all social icons
function hidesocial_setting() {
   $options = get_option('plugin_options');
   $items = array("no", "yes");
   echo "<select name='plugin_options[hidesocial]'>";
   foreach ($items as $item) {
      $selected = ( $options['hidesocial'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Harvet emails description
function harvest_desc_setting() {
   $options = get_option('plugin_options');
}

// Use SQL?
function useSQL_setting() {
   $options = get_option('plugin_options');
   $items = array("no", "yes");

   echo "<select name='plugin_options[useSQL]'>";
   foreach ($items as $item) {
      $selected = ( $options['useSQL'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// DB hostname
function dbhost_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[dbhost]' type='text' value='{$options['dbhost']}' />";
}

// DB database
function dbdatabase_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[dbdatabase]' type='text' value='{$options['dbdatabase']}' />";
}

// DB username
function dbusername_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[dbusername]' type='text' value='{$options['dbusername']}' />";
}

// DB password
function dbpassword_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[dbpassword]' type='text' value='{$options['dbpassword']}' />";
}

// Use XML?
function useXML_setting() {
   $options = get_option('plugin_options');
   $items = array("no", "yes");

   echo "<select name='plugin_options[useXML]'>";
   foreach ($items as $item) {
      $selected = ( $options['useXML'] === $item ) ? 'selected = "selected"' : '';
      echo "<option value='$item' $selected>$item</option>";
   }
   echo "</select>";
}

// Confirmation letter description
function confletter_desc_setting() {
   $options = get_option('plugin_options');
}

// From Name
function email_sender_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[email_sender]' type='text' value='{$options['email_sender']}' />";
}

// From
function email_from_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[email_from]' type='text' value='{$options['email_from']}' />";
}

// Subject
function email_subject_setting() {
   $options = get_option('plugin_options');
   echo "<input name='plugin_options[email_subject]' type='text' value='{$options['email_subject']}' />";
}

// Message
function email_body_setting() {
   $options = get_option('plugin_options');
   echo "<textarea name='plugin_options[email_body]' rows='10' cols='60' type='textarea'>{$options['email_body']}</textarea>";
}





function validate_setting($plugin_options) {
   $keys = array_keys($_FILES);
   $i = 0;

   foreach ($_FILES as $image) {
      // if a files was upload
      if ($image['size']) {
         // if it is an image
         if (preg_match('/(jpg|jpeg|png|gif)$/', $image['type'])) {
            $override = array('test_form' => false);
            $file = wp_handle_upload($image, $override);

            $plugin_options[$keys[$i]] = $file['url'];
         } else {
            $options = get_option('plugin_options');
            $plugin_options[$keys[$i]] = $options[$logo];
            wp_die('No image was uploaded.');
         }
      }

      // else, retain the image that's already on file.
      else {
         $options = get_option('plugin_options');
         $plugin_options[$keys[$i]] = $options[$keys[$i]];
      }
      $i++;
   }

   return $plugin_options;
}

function section_cb() {}

// Add stylesheet
add_action('admin_head', 'admin_register_head');

function admin_register_head() {
   $url = get_bloginfo('template_directory') . '/functions/options_page.css';
   echo "<link rel='stylesheet' href='$url' />\n";
}